<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/zensical/zensical/master/.github/assets/zensical-dark.png">
    <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/zensical/zensical/master/.github/assets/zensical.png">
    <img alt="Zensical" src="https://raw.githubusercontent.com/zensical/zensical/master/.github/assets/zensical.png" width="290" height="240">
  </picture>
</p>

<p align="center">
  <strong>
    A modern static site generator built by the creators of
    <a href="https://github.com/squidfunk/mkdocs-material/">Material for MkDocs</a>
  </strong>
</p>

<p align="center">
  <a href="https://github.com/zensical/zensical/actions"><img
    src="https://github.com/zensical/zensical/actions/workflows/build.yml/badge.svg"
    alt="Build"
  /></a>
  <a href="https://pypi.org/project/zensical"><img
    src="https://img.shields.io/pypi/v/zensical?logo=python&logoColor=white&label=PyPI"
    alt="Python Package Index"
  /></a>
  <a href="https://discord.com/invite/hqXRNq9CjT"><img
    src="https://img.shields.io/discord/1289187620659789824?logo=discord&logoColor=white&label=Discord"
    alt="Discord"
  /></a>
</p>

<p align="center">
  <a href="https://zensical.org/"><strong>Home</strong></a>
  &middot;
  <a href="https://zensical.org/docs/get-started/"><strong>Get started</strong></a>
  &middot;
  <a href="https://zensical.org/compatibility/"><strong>Compatibility</strong></a>
  &middot;
  <a href="https://zensical.org/about/roadmap/"><strong>Roadmap</strong></a>
  &middot;
  <a href="https://zensical.org/about/newsletter/"><strong>Newsletter</strong></a>
  &middot;
  <a href="https://zensical.org/spark/"><strong>Zensical Spark</strong></a>
</p>

<p align="center">
  Write your documentation in Markdown and create a professional static site for
  your Open Source or commercial project in minutes – searchable, customizable,
  more than 60 languages, for all devices.
</p>

<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/zensical/zensical/master/.github/assets/screenshot-dark.png">
    <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/zensical/zensical/master/.github/assets/screenshot.png">
    <img alt="Zensical" src="https://raw.githubusercontent.com/zensical/zensical/master/.github/assets/screenshot.png">
  </picture>
</p>

<p align="center">
  <em>
    Visit our documentation at
    <a href="https://zensical.org/docs/">zensical.org/docs/</a>.
  </em>
</p>
